@@ -52,7 +52,7 @@ typedef struct {
 static security_context_t
 SELinuxCopyContext(char *ptr, unsigned len)
 {
-    security_context_t copy = xalloc(len + 1);
+    security_context_t copy = malloc(len + 1);
     if (!copy)
 	return NULL;
     strncpy(copy, ptr, len);
@@ -71,14 +71,13 @@ ProcSELinuxQueryVersion(ClientPtr client)
     rep.server_major = SELINUX_MAJOR_VERSION;
     rep.server_minor = SELINUX_MINOR_VERSION;
     if (client->swapped) {
-	int n;
-	swaps(&rep.sequenceNumber, n);
-	swapl(&rep.length, n);
-	swaps(&rep.server_major, n);
-	swaps(&rep.server_minor, n);
+	swaps(&rep.sequenceNumber);
+	swapl(&rep.length);
+	swaps(&rep.server_major);
+	swaps(&rep.server_minor);
     }
     WriteToClient(client, sizeof(rep), (char *)&rep);
-    return (client->noClientException);
+    return Success;
 }
 
 static int
@@ -100,16 +99,15 @@ SELinuxSendContextReply(ClientPtr client, security_id_t sid)
     rep.context_len = len;
 
     if (client->swapped) {
-	int n;
-	swapl(&rep.length, n);
-	swaps(&rep.sequenceNumber, n);
-	swapl(&rep.context_len, n);
+	swapl(&rep.length);
+	swaps(&rep.sequenceNumber);
+	swapl(&rep.context_len);
     }
 
     WriteToClient(client, sizeof(SELinuxGetContextReply), (char *)&rep);
     WriteToClient(client, len, ctx);
     freecon(ctx);
-    return client->noClientException;
+    return Success;
 }
 
 static int
@@ -141,7 +139,7 @@ ProcSELinuxSetCreateContext(ClientPtr client, unsigned offset)
 	    rc = BadValue;
     }
 
-    xfree(ctx);
+    free(ctx);
     return rc;
 }
 
@@ -198,7 +196,7 @@ ProcSELinuxSetDeviceContext(ClientPtr client)
 
     rc = Success;
 out:
-    xfree(ctx);
+    free(ctx);
     return rc;
 }
 
@@ -231,13 +229,11 @@ ProcSELinuxGetDrawableContext(ClientPtr client)
     REQUEST(SELinuxGetContextReq);
     REQUEST_SIZE_MATCH(SELinuxGetContextReq);
 
-    rc = dixLookupDrawable(&pDraw, stuff->id, client,
-			   M_WINDOW | M_DRAWABLE_PIXMAP,
-			   DixGetAttrAccess);
+    rc = dixLookupDrawable(&pDraw, stuff->id, client, 0, DixGetAttrAccess);
     if (rc != Success)
 	return rc;
 
-    if (pDraw->type == M_DRAWABLE_PIXMAP)
+    if (pDraw->type == DRAWABLE_PIXMAP)
 	privatePtr = &((PixmapPtr)pDraw)->devPrivates;
     else
 	privatePtr = &((WindowPtr)pDraw)->devPrivates;
@@ -334,18 +330,18 @@ SELinuxFreeItems(SELinuxListItemRec *items, int count)
 	freecon(items[k].octx);
 	freecon(items[k].dctx);
     }
-    xfree(items);
+    free(items);
 }
 
 static int
 SELinuxSendItemsToClient(ClientPtr client, SELinuxListItemRec *items,
 			 int size, int count)
 {
-    int rc, k, n, pos = 0;
+    int rc, k, pos = 0;
     SELinuxListItemsReply rep;
     CARD32 *buf;
 
-    buf = xcalloc(size, sizeof(CARD32));
+    buf = calloc(size, sizeof(CARD32));
     if (size && !buf) {
 	rc = BadAlloc;
 	goto out;
@@ -355,17 +351,17 @@ SELinuxSendItemsToClient(ClientPtr client, SELinuxListItemRec *items,
     for (k = 0; k < count; k++) {
 	buf[pos] = items[k].id;
 	if (client->swapped)
-	    swapl(buf + pos, n);
+	    swapl(buf + pos);
 	pos++;
 
 	buf[pos] = items[k].octx_len * 4;
 	if (client->swapped)
-	    swapl(buf + pos, n);
+	    swapl(buf + pos);
 	pos++;
 
 	buf[pos] = items[k].dctx_len * 4;
 	if (client->swapped)
-	    swapl(buf + pos, n);
+	    swapl(buf + pos);
 	pos++;
 
 	memcpy((char *)(buf + pos), items[k].octx, strlen(items[k].octx) + 1);
@@ -381,17 +377,17 @@ SELinuxSendItemsToClient(ClientPtr client, SELinuxListItemRec *items,
     rep.count = count;
 
     if (client->swapped) {
-	swapl(&rep.length, n);
-	swaps(&rep.sequenceNumber, n);
-	swapl(&rep.count, n);
+	swapl(&rep.length);
+	swaps(&rep.sequenceNumber);
+	swapl(&rep.count);
     }
 
     WriteToClient(client, sizeof(SELinuxListItemsReply), (char *)&rep);
     WriteToClient(client, size * 4, (char *)buf);
 
     /* Free stuff and return */
-    rc = client->noClientException;
-    xfree(buf);
+    rc = Success;
+    free(buf);
 out:
     SELinuxFreeItems(items, count);
     return rc;
@@ -417,7 +413,7 @@ ProcSELinuxListProperties(ClientPtr client)
     count = 0;
     for (pProp = wUserProps(pWin); pProp; pProp = pProp->next)
 	count++;
-    items = xcalloc(count, sizeof(SELinuxListItemRec));
+    items = calloc(count, sizeof(SELinuxListItemRec));
     if (count && !items)
 	return BadAlloc;
 
@@ -451,7 +447,7 @@ ProcSELinuxListSelections(ClientPtr client)
     count = 0;
     for (pSel = CurrentSelections; pSel; pSel = pSel->next)
 	count++;
-    items = xcalloc(count, sizeof(SELinuxListItemRec));
+    items = calloc(count, sizeof(SELinuxListItemRec));
     if (count && !items)
 	return BadAlloc;
 
@@ -530,12 +526,6 @@ ProcSELinuxDispatch(ClientPtr client)
 static int
 SProcSELinuxQueryVersion(ClientPtr client)
 {
-    REQUEST(SELinuxQueryVersionReq);
-    int n;
-
-    REQUEST_SIZE_MATCH(SELinuxQueryVersionReq);
-    swaps(&stuff->client_major, n);
-    swaps(&stuff->client_minor, n);
     return ProcSELinuxQueryVersion(client);
 }
 
@@ -543,10 +533,9 @@ static int
 SProcSELinuxSetCreateContext(ClientPtr client, unsigned offset)
 {
     REQUEST(SELinuxSetCreateContextReq);
-    int n;
 
     REQUEST_AT_LEAST_SIZE(SELinuxSetCreateContextReq);
-    swapl(&stuff->context_len, n);
+    swapl(&stuff->context_len);
     return ProcSELinuxSetCreateContext(client, offset);
 }
 
@@ -554,11 +543,10 @@ static int
 SProcSELinuxSetDeviceContext(ClientPtr client)
 {
     REQUEST(SELinuxSetContextReq);
-    int n;
 
     REQUEST_AT_LEAST_SIZE(SELinuxSetContextReq);
-    swapl(&stuff->id, n);
-    swapl(&stuff->context_len, n);
+    swapl(&stuff->id);
+    swapl(&stuff->context_len);
     return ProcSELinuxSetDeviceContext(client);
 }
 
@@ -566,10 +554,9 @@ static int
 SProcSELinuxGetDeviceContext(ClientPtr client)
 {
     REQUEST(SELinuxGetContextReq);
-    int n;
 
     REQUEST_SIZE_MATCH(SELinuxGetContextReq);
-    swapl(&stuff->id, n);
+    swapl(&stuff->id);
     return ProcSELinuxGetDeviceContext(client);
 }
 
@@ -577,10 +564,9 @@ static int
 SProcSELinuxGetDrawableContext(ClientPtr client)
 {
     REQUEST(SELinuxGetContextReq);
-    int n;
 
     REQUEST_SIZE_MATCH(SELinuxGetContextReq);
-    swapl(&stuff->id, n);
+    swapl(&stuff->id);
     return ProcSELinuxGetDrawableContext(client);
 }
 
@@ -588,11 +574,10 @@ static int
 SProcSELinuxGetPropertyContext(ClientPtr client, pointer privKey)
 {
     REQUEST(SELinuxGetPropertyContextReq);
-    int n;
 
     REQUEST_SIZE_MATCH(SELinuxGetPropertyContextReq);
-    swapl(&stuff->window, n);
-    swapl(&stuff->property, n);
+    swapl(&stuff->window);
+    swapl(&stuff->property);
     return ProcSELinuxGetPropertyContext(client, privKey);
 }
 
@@ -600,10 +585,9 @@ static int
 SProcSELinuxGetSelectionContext(ClientPtr client, pointer privKey)
 {
     REQUEST(SELinuxGetContextReq);
-    int n;
 
     REQUEST_SIZE_MATCH(SELinuxGetContextReq);
-    swapl(&stuff->id, n);
+    swapl(&stuff->id);
     return ProcSELinuxGetSelectionContext(client, privKey);
 }
 
@@ -611,10 +595,9 @@ static int
 SProcSELinuxListProperties(ClientPtr client)
 {
     REQUEST(SELinuxGetContextReq);
-    int n;
 
     REQUEST_SIZE_MATCH(SELinuxGetContextReq);
-    swapl(&stuff->id, n);
+    swapl(&stuff->id);
     return ProcSELinuxListProperties(client);
 }
 
@@ -622,10 +605,9 @@ static int
 SProcSELinuxGetClientContext(ClientPtr client)
 {
     REQUEST(SELinuxGetContextReq);
-    int n;
 
     REQUEST_SIZE_MATCH(SELinuxGetContextReq);
-    swapl(&stuff->id, n);
+    swapl(&stuff->id);
     return ProcSELinuxGetClientContext(client);
 }
 
@@ -633,9 +615,8 @@ static int
 SProcSELinuxDispatch(ClientPtr client)
 {
     REQUEST(xReq);
-    int n;
 
-    swaps(&stuff->length, n);
+    swaps(&stuff->length);
 
     switch (stuff->data) {
     case X_SELinuxQueryVersion:
