@@ -75,12 +75,10 @@ extern int ExtEventIndex;
 int
 SProcXGetDeviceDontPropagateList(ClientPtr client)
 {
-    char n;
-
     REQUEST(xGetDeviceDontPropagateListReq);
-    swaps(&stuff->length, n);
+    swaps(&stuff->length);
     REQUEST_SIZE_MATCH(xGetDeviceDontPropagateListReq);
-    swapl(&stuff->window, n);
+    swapl(&stuff->window);
     return (ProcXGetDeviceDontPropagateList(client));
 }
 
@@ -115,11 +113,11 @@ ProcXGetDeviceDontPropagateList(ClientPtr client)
 
     if ((others = wOtherInputMasks(pWin)) != 0) {
 	for (i = 0; i < EMASKSIZE; i++)
-	    tbuf = ClassFromMask(NULL, others->dontPropagateMask[i], i,
+	    ClassFromMask(NULL, others->dontPropagateMask[i], i,
 				 &count, COUNT);
 	if (count) {
 	    rep.count = count;
-	    buf = (XEventClass *) xalloc(rep.count * sizeof(XEventClass));
+	    buf = (XEventClass *) malloc(rep.count * sizeof(XEventClass));
 	    rep.length = bytes_to_int32(rep.count * sizeof(XEventClass));
 
 	    tbuf = buf;
@@ -134,7 +132,7 @@ ProcXGetDeviceDontPropagateList(ClientPtr client)
     if (count) {
 	client->pSwapReplyFunc = (ReplySwapPtr) Swap32Write;
 	WriteSwappedDataToClient(client, count * sizeof(XEventClass), buf);
-	xfree(buf);
+	free(buf);
     }
     return Success;
 }
@@ -164,7 +162,7 @@ XEventClass
 			*buf++ = (id << 8) | EventInfo[j].type;
 		}
 	}
-    return (buf);
+    return buf;
 }
 
 /***********************************************************************
@@ -178,10 +176,8 @@ void
 SRepXGetDeviceDontPropagateList(ClientPtr client, int size,
 				xGetDeviceDontPropagateListReply * rep)
 {
-    char n;
-
-    swaps(&rep->sequenceNumber, n);
-    swapl(&rep->length, n);
-    swaps(&rep->count, n);
+    swaps(&rep->sequenceNumber);
+    swapl(&rep->length);
+    swaps(&rep->count);
     WriteToClient(client, size, (char *)rep);
 }
