@@ -63,6 +63,7 @@
 #include "Configint.h"
 #include <X11/Xfuncproto.h>
 #include "Xprintf.h"
+#include "optionstr.h"
 
 extern LexRec val;
 
@@ -159,7 +160,7 @@ xf86parseFlagsSection (void)
 			break;
 
 		case EOF_TOKEN:
-			Error (UNEXPECTED_EOF_MSG, NULL);
+			Error (UNEXPECTED_EOF_MSG);
 			break;
 		default:
 			Error (INVALID_KEYWORD_MSG, xf86tokenString ());
@@ -203,7 +204,7 @@ addNewOption2 (XF86OptionPtr head, char *name, char *val, int used)
 		free(new->opt_val);
 	}
 	else
-		new = calloc (1, sizeof (XF86OptionRec));
+		new = calloc (1, sizeof (*new));
 	new->opt_name = name;
 	new->opt_val = val;
 	new->opt_used = used;
@@ -284,7 +285,7 @@ xf86newOption(char *name, char *value)
 {
 	XF86OptionPtr opt;
 
-	opt = calloc(1, sizeof (XF86OptionRec));
+	opt = calloc(1, sizeof (*opt));
 	if (!opt)
 		return NULL;
 
@@ -329,7 +330,7 @@ xf86findOption (XF86OptionPtr list, const char *name)
  * returned.  If the option is not found, a NULL is returned.
  */
 
-char *
+const char *
 xf86findOptionValue (XF86OptionPtr list, const char *name)
 {
 	XF86OptionPtr p = xf86findOption (list, name);
@@ -439,7 +440,7 @@ xf86parseOption(XF86OptionPtr head)
 	int token;
 
 	if ((token = xf86getSubToken(&comment)) != STRING) {
-		xf86parseError(BAD_OPTION_MSG, NULL);
+		xf86parseError(BAD_OPTION_MSG);
 		free(comment);
 		return head;
 	}
