@@ -221,6 +221,14 @@ GrabWindow(
 	GrabParameters*        /* param */,
 	GrabMask*              /* eventMask */);
 
+extern int
+GrabTouch(
+       ClientPtr              /* client */,
+       DeviceIntPtr           /* dev */,
+       DeviceIntPtr           /* mod_dev */,
+       GrabParameters*        /* param */,
+       GrabMask*              /* eventMask */);
+
 extern int
 SelectForWindow(
 	DeviceIntPtr           /* dev */,
@@ -245,6 +253,10 @@ InputClientGone(
 	WindowPtr              /* pWin */,
 	XID                    /* id */);
 
+extern void
+WindowGone(
+	WindowPtr              /* win */);
+
 extern int
 SendEvent (
 	ClientPtr              /* client */,
